@@ -20,7 +20,7 @@
 
 import os
 
-from .cwproxy import CWProxy, SignedRequestAuth
+from .cwproxy import CWProxy, SignedRequestAuth, MD5SignedRequestAuth
 
 
 def cwproxy_for(instance, **kw):
@@ -89,7 +89,7 @@ def cwproxy_for(instance, **kw):
     if not url:
         raise ValueError('Missing "url" configuration option')
 
-    if auth_mech == "signedrequest":
+    if auth_mech in ("signedrequest", "md5signedrequest"):
         tokenid = cfg.get("token-id")
         secret = cfg.get("secret")
         if not tokenid or not secret:
@@ -97,7 +97,10 @@ def cwproxy_for(instance, **kw):
                 'Missing "token-id" or "secret" configuration '
                 "option for signedrequest"
             )
-        auth = SignedRequestAuth(tokenid, secret)
+        if auth_mech == "signedrequest":
+            auth = SignedRequestAuth(tokenid, secret)
+        elif auth_mech == "md5signedrequest":
+            auth = MD5SignedRequestAuth(tokenid, secret)
 
     else:
         raise ValueError(
@@ -135,9 +138,9 @@ def get_config():
         with open(cfgfile) as f:
             cfg = yaml.load(f)
     else:
-        from six.moves import configparser as cp
+        from configparser import ConfigParser
 
-        cp = cp.ConfigParser()
+        cp = ConfigParser()
         cp.read(cfgfile)
         cfg = {section: dict(cp.items(section)) for section in cp.sections()}
     return cfg
