@@ -24,7 +24,9 @@
 >>> print(a.json())
 """
 
+import sys
 import json
+import warnings
 import requests
 import hmac
 import hashlib
@@ -50,28 +52,33 @@ RQLIO_API = "1.0"
 class SignedRequestAuth(requests.auth.AuthBase):
     """Auth implementation for CubicWeb with cube signedrequest"""
 
-    HEADERS_TO_SIGN = ("Content-SHA512", "Content-Type", "Date")
+    hash_algorithm = "SHA512"
 
     def __init__(self, token_id, secret):
         self.token_id = token_id
         self.secret = secret
 
+    def get_headers_to_sign(self):
+        return ("Content-%s" % self.hash_algorithm.upper(), "Content-Type", "Date")
+
     def __call__(self, req):
         content = b""
         if req.body:
             content = req.body
         if isinstance(content, str):
             content = content.encode("utf-8")
-        req.headers["Content-SHA512"] = hashlib.sha512(content).hexdigest()
+        req.headers["Content-%s" % self.hash_algorithm.upper()] = getattr(
+            hashlib, self.hash_algorithm.lower()
+        )(content).hexdigest()
         content_to_sign = (
             req.method
             + req.url
-            + "".join(req.headers.get(field, "") for field in self.HEADERS_TO_SIGN)
+            + "".join(req.headers.get(field, "") for field in self.get_headers_to_sign())
         )
         content_signed = hmac.new(
             self.secret.encode("utf-8"),
             content_to_sign.encode("utf-8"),
-            digestmod="sha512",
+            digestmod=self.hash_algorithm.lower(),
         ).hexdigest()
         req.headers["Authorization"] = "Cubicweb %s:%s" % (
             self.token_id,
@@ -80,6 +87,26 @@ class SignedRequestAuth(requests.auth.AuthBase):
         return req
 
 
+class MD5SignedRequestAuth(SignedRequestAuth):
+    """
+    Like SignedRequestAuth except it signed its requests with MD5
+
+    This is INSECURE, DON'T USED IT except for compatibility reasons
+    """
+
+    hash_algorithm = "MD5"
+
+    def __init__(self, token_id, secret):
+        super(MD5SignedRequestAuth, self).__init__(token_id, secret)
+        warning_message = (
+            "WARNING: you are using an INSECURE SIGNING HASH algorithm (md5), please move to "
+            "sha512 by using the SignedRequestAuth instead of the MD5SignedRequestAuth. The "
+            "MD5SignedRequestAuth class will be removed in the future"
+        )
+        sys.stderr.write(warning_message + "\n")
+        warnings.warn(warning_message, DeprecationWarning)
+
+
 def date_header_value() -> str:
     return datetime.utcnow().strftime("%a, %d %b %Y %H:%M:%S GMT")
 
